hk32-partial-hal 0.3.1

HK32 partial HAL
docs.rs failed to build hk32-partial-hal-0.3.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.